@@ -1,16 +1,16 @@
-from autoarray import conf
 from autoarray import preprocess
 from autoarray.dataset.imaging import Imaging
 from autoarray.dataset.interferometer import Interferometer
 from autoarray.mask.mask import Mask
 from autoarray.operators.convolver import Convolver
-from autoarray.operators.inversion import pixelizations as pix, regularization as reg
-from autoarray.operators.inversion.inversions import inversion as Inversion
-from autoarray.operators.inversion.mappers import mapper as Mapper
+from autoarray.inversion import pixelizations as pix, regularization as reg
+from autoarray.inversion.pixelizations import SettingsPixelization
+from autoarray.inversion.inversions import inversion as Inversion, SettingsInversion
+from autoarray.inversion.mappers import mapper as Mapper
 from autoarray.operators.transformer import TransformerDFT
 from autoarray.operators.transformer import TransformerNUFFT
-from autoarray.operators.transformer import TransformerNUFFTLops
-from autoarray.structures.arrays import Values
+from autoarray.operators.transformer import TransformerNUFFT
+from autoarray.structures.arrays import Array, Values
 from autoarray.structures.grids import (
     Grid,
     GridIterate,
@@ -20,9 +20,11 @@ from autoarray.structures.grids import (
     GridVoronoi,
 )
 from autoarray.structures.kernel import Kernel
-from autoarray.structures.visibilities import Visibilities
+from autoarray.structures.visibilities import Visibilities, VisibilitiesNoiseMap
 from autogalaxy import dimensions as dim
 from autogalaxy import util
+from autogalaxy.dataset.imaging import SettingsMaskedImaging
+from autogalaxy.dataset.interferometer import SettingsMaskedInterferometer
 from autogalaxy.galaxy.fit_galaxy import FitGalaxy
 from autogalaxy.galaxy.galaxy import Galaxy, HyperGalaxy, Redshift
 from autogalaxy.galaxy.galaxy_data import GalaxyData
@@ -42,7 +44,6 @@ from autogalaxy.profiles import (
     mass_profiles as mp,
     light_and_mass_profiles as lmp,
 )
-from autogalaxy.structures.arrays import Array
 from autogalaxy.util import convert
 
 from . import aggregator as agg
@@ -50,17 +51,18 @@ from . import plot
 from .dataset.imaging import MaskedImaging, SimulatorImaging
 from .dataset.interferometer import MaskedInterferometer, SimulatorInterferometer
 from .fit.fit import FitImaging, FitInterferometer
-from .fit.fit import FitPositions
+from .fit.fit_positions import FitPositionsSourcePlaneMaxSeparation
+from .lens.settings import SettingsLens
 from .lens.ray_tracing import Tracer
-from .lens.positions_solver import PositionsSolver
-from .pipeline.setup import PipelineSetup
+from .lens.positions_solver import PositionsFinder
+from .pipeline.setup import SetupPipeline
 from .pipeline import slam
-from .pipeline.phase.settings import PhaseSettingsImaging
-from .pipeline.phase.settings import PhaseSettingsInterferometer
+from .pipeline.phase.settings import SettingsPhaseImaging
+from .pipeline.phase.settings import SettingsPhaseInterferometer
 from .pipeline.phase.imaging.phase import PhaseImaging
 from .pipeline.phase.interferometer.phase import PhaseInterferometer
 from .pipeline.phase.extensions.stochastic_phase import StochasticPhase
 from .pipeline.phase.phase_galaxy import PhaseGalaxy
 from .pipeline.pipeline import PipelineDataset, PipelinePositions
 
-__version__ = '1.3.3'
+__version__ = '1.5.0'
