@@ -12,6 +12,7 @@ class SLaM:
         self.source = source
         self.light = light
         self.mass = mass
+        self.mass.disk_as_sersic = self.light.disk_as_sersic
 
     def set_source_type(self, source_type):
 
@@ -202,7 +203,7 @@ class SLaM:
                 )
 
 
-class HyperSetup(setup.PipelineSetup):
+class SLaMHyper(setup.SetupPipeline):
     def __init__(
         self,
         hyper_galaxies=False,
@@ -217,7 +218,7 @@ class HyperSetup(setup.PipelineSetup):
         """The setup of a pipeline, which controls how PyAutoLens template pipelines runs, for example controlling
         assumptions about the lens's light profile bulge-disk model or if shear is included in the mass model.
 
-        Users can write their own pipelines which do not use or require the *PipelineSetup* class.
+        Users can write their own pipelines which do not use or require the *SetupPipeline* class.
 
         This class enables pipeline tagging, whereby the setup of the pipeline is used in the template pipeline
         scripts to tag the output path of the results depending on the setup parameters. This allows one to fit
@@ -294,7 +295,7 @@ class HyperSetup(setup.PipelineSetup):
             )
 
 
-class SourceSetup(setup.PipelineSetup):
+class SLaMSource(setup.SetupPipeline):
     def __init__(
         self,
         pixelization=None,
@@ -458,7 +459,7 @@ class SourceSetup(setup.PipelineSetup):
         return mass
 
 
-class LightSetup(setup.PipelineSetup):
+class SLaMLight(setup.SetupPipeline):
     def __init__(
         self,
         align_bulge_disk_centre=False,
@@ -495,21 +496,32 @@ class LightSetup(setup.PipelineSetup):
             )
 
 
-class MassSetup(setup.PipelineSetup):
+class SLaMMass(setup.SetupPipeline):
     def __init__(
         self,
         no_shear=False,
+        fix_lens_light=False,
+        constant_mass_to_light_ratio=False,
+        bulge_mass_to_light_ratio_gradient=False,
+        disk_mass_to_light_ratio_gradient=False,
         align_light_dark_centre=False,
         align_bulge_dark_centre=False,
-        fix_lens_light=False,
+        include_smbh=False,
+        smbh_centre_fixed=True,
     ):
 
         super().__init__(
             no_shear=no_shear,
+            constant_mass_to_light_ratio=constant_mass_to_light_ratio,
+            bulge_mass_to_light_ratio_gradient=bulge_mass_to_light_ratio_gradient,
+            disk_mass_to_light_ratio_gradient=disk_mass_to_light_ratio_gradient,
             align_light_dark_centre=align_light_dark_centre,
             align_bulge_dark_centre=align_bulge_dark_centre,
+            include_smbh=include_smbh,
+            smbh_centre_fixed=smbh_centre_fixed,
         )
 
+        self.disk_as_sersic = None
         self.fix_lens_light = fix_lens_light
         self.type_tag = None
 
@@ -522,6 +534,7 @@ class MassSetup(setup.PipelineSetup):
             + self.no_shear_tag
             + self.align_light_dark_centre_tag
             + self.align_bulge_dark_centre_tag
+            + self.include_smbh_tag
             + self.fix_lens_light_tag
         )
 
@@ -542,7 +555,7 @@ class MassSetup(setup.PipelineSetup):
 
     @property
     def shear_from_previous_pipeline(self):
-        """Return the shear PriorModel from a previous pipeline, where:
+        """Return the shear _PriorModel_ from a previous pipeline, where:
 
         1) If the shear was included in the *Source* pipeline and *no_shear* is *False* in the *Mass* object, it is
            returned using this pipeline result as a model.
