@@ -82,7 +82,7 @@ keep the number of parameters down and the phases running fast, but we wouldn't
 """
 __Settings__
 
-The *PhaseSettingsImaging* describe how the model is fitted to the data in the log likelihood function. We discussed
+The *SettingsPhaseImaging* describe how the model is fitted to the data in the log likelihood function. We discussed
 these in chapter 2, and a full description of all settings can be found in the example script:
 
  'autolens_workspace/examples/model/customize/settings.py'.
@@ -91,7 +91,9 @@ The settings chosen here are applied to all phases in the pipeline.
 """
 
 # %%
-settings = al.PhaseSettingsImaging(grid_class=al.Grid, sub_size=2)
+settings_masked_imaging = al.SettingsMaskedImaging(grid_class=al.Grid, sub_size=2)
+
+settings = al.SettingsPhaseImaging(settings_masked_imaging=settings_masked_imaging)
 
 # %%
 """
@@ -109,7 +111,7 @@ to different output folders and thus not clash with one another!
 """
 
 # %%
-setup = al.PipelineSetup(no_shear=False, folders=["howtolens", "c3_t3_complex_source"])
+setup = al.SetupPipeline(no_shear=False, folders=["c3_t3_complex_source"])
 
 # %%
 """
