@@ -50,8 +50,8 @@ def make_pipeline(setup, settings):
     of the output. In the pipeline runner we pass the folders ["howtolens", c3_t1_lens_and_source], making the
     output of this pipeline 'autolens_workspace/output/howtolens/c3_t1_lens_and_source/pipeline__light_and_source'.
 
-    The output path is also tagged according to the _PipelineSetup_, in an analagous fashion to how the 
-    _PhaseSettingsImaging_ tagged the output paths of phases. In this example, we do not use an _ExternalShear_
+    The output path is also tagged according to the _SetupPipeline_, in an analagous fashion to how the 
+    _SettingsPhaseImaging_ tagged the output paths of phases. In this example, we do not use an _ExternalShear_
     in the mass model, and the pipeline is tagged accordingly.
     """
 
@@ -84,7 +84,7 @@ def make_pipeline(setup, settings):
            
     In phase 2, we fit the source-galaxy's light. Thus, we want to fix the lens light model to the model inferred
     in phase 1, ensuring the image we fit is lens subtracted. We do this below by passing the lens light as an
-    'instance' object, a trick we use in nearly all pipelines!
+ 'instance' object, a trick we use in nearly all pipelines!
 
     By passing an 'instance', we are telling __PyAutoLens__ that we want it to pass the maximum log likelihood result of
     that phase and use those parameters as fixed values in the model. The model parameters passed as an 'instance' are
