@@ -14,16 +14,12 @@ def make_pipeline(name, folders, search=af.DynestyStatic()):
 
     lens.mass.centre_0 = af.UniformPrior(lower_limit=-0.01, upper_limit=0.01)
     lens.mass.centre_1 = af.UniformPrior(lower_limit=-0.01, upper_limit=0.01)
-    lens.mass.axis_ratio = af.UniformPrior(lower_limit=0.65, upper_limit=0.75)
-    lens.mass.phi = af.UniformPrior(lower_limit=40.0, upper_limit=50.0)
     lens.mass.einstein_radius = af.UniformPrior(lower_limit=1.55, upper_limit=1.65)
 
     source = al.GalaxyModel(redshift=1.0, light=al.lp.EllipticalSersic)
 
     source.light.centre_0 = af.UniformPrior(lower_limit=-0.01, upper_limit=0.01)
     source.light.centre_1 = af.UniformPrior(lower_limit=-0.01, upper_limit=0.01)
-    source.light.axis_ratio = af.UniformPrior(lower_limit=0.75, upper_limit=0.85)
-    source.light.phi = af.UniformPrior(lower_limit=50.0, upper_limit=70.0)
     source.light.intensity = af.UniformPrior(lower_limit=0.35, upper_limit=0.45)
     source.light.effective_radius = af.UniformPrior(lower_limit=0.45, upper_limit=0.55)
     source.light.sersic_index = af.UniformPrior(lower_limit=0.9, upper_limit=1.1)
@@ -33,12 +29,9 @@ def make_pipeline(name, folders, search=af.DynestyStatic()):
         folders=folders,
         galaxies=dict(lens=lens, source=source),
         search=search,
+        settings=al.SettingsPhaseImaging(),
     )
 
-    phase1.search.const_efficiency_mode = True
-    phase1.search.n_live_points = 40
-    phase1.search.facc = 0.8
-
     class GridPhase(af.as_grid_search(phase_class=al.PhaseImaging, parallel=False)):
         @property
         def grid_priors(self):
@@ -54,8 +47,6 @@ def make_pipeline(name, folders, search=af.DynestyStatic()):
     subhalo.mass.centre_0 = af.UniformPrior(lower_limit=-2.5, upper_limit=2.5)
     subhalo.mass.centre_1 = af.UniformPrior(lower_limit=-2.5, upper_limit=2.5)
 
-    search = af.DynestyStatic()(const_efficiency_mode=True)
-
     phase2 = GridPhase(
         phase_name="phase_2",
         folders=folders,
@@ -65,11 +56,10 @@ def make_pipeline(name, folders, search=af.DynestyStatic()):
             source=af.last.instance.galaxies.source,
         ),
         search=search,
+        settings=al.SettingsPhaseImaging(),
         number_of_steps=2,
     )
 
-    phase2.search.const_efficiency_mode = True
-
     phase3 = al.PhaseImaging(
         phase_name="phase_3__subhalo_refine",
         folders=folders,
@@ -78,11 +68,10 @@ def make_pipeline(name, folders, search=af.DynestyStatic()):
             subhalo=phase2.result.model.galaxies.subhalo,
             source=af.last[-1].instance.galaxies.source,
         ),
+        settings=al.SettingsPhaseImaging(),
         search=af.DynestyStatic(),
     )
 
-    phase3.search.const_efficiency_mode = True
-
     return al.PipelineDataset(name, phase1, phase2, phase3)
 
 
