@@ -26,12 +26,12 @@ mask = al.Mask.elliptical(
 
 # The lines of code below do everything we're used to, that is, setup an image and its grid, mask it, trace it
 # via a tracer, setup the rectangular mapper, etc.
-lens_galaxy = al.LightSetup(
+lens_galaxy = al.SLaMLight(
     mass=al.mp.EllipticalIsothermal(
         centre=(1.0, 1.0), einstein_radius=1.6, elliptical_comps=(0.17647, 0.0)
     )
 )
-source_galaxy = al.LightSetup(
+source_galaxy = al.SLaMLight(
     pixelization=al.pix.VoronoiMagnification(shape=(20, 20)),
     regularization=al.reg.instance(coefficient=1.0),
 )
